@@ -1,5 +1,5 @@
 from . import importer
 
-importer.install()
+importer.install(check_options=True)
 
 from django.core.management import execute_from_command_line  # noqa
