@@ -2,7 +2,7 @@ from invoke import run, task
 
 
 @task
-def test(label='configurations'):
+def test(label='tests'):
     run('flake8 configurations --ignore=E501,E127,E128,E124')
     run('./manage.py test {0} -v2'.format(label))
 
